@@ -1,5 +1,5 @@
 from .exception import TokenThrottlerException
-from .throttler_config import ThrottlerConfig
+from .throttler_config import ThrottlerConfig, ThrottlerConfigGlobal, default_config
 from .token_bucket import TokenBucket
 from .token_throttler import TokenThrottler
 from .token_throttler_async import TokenThrottlerAsync
