@@ -1,3 +1,3 @@
 from .bucket_storage import BucketStorage
 from .bucket_storage_async import BucketStorageAsync
-from .memory_storage import RuntimeStorage
+from .runtime_storage import RuntimeStorage
